#!/bin/bash

#
# Configuration Identifier
#
#   i386:    x86
#   x86_64:  x64
#

OS=`uname -o`
MACHINE=`uname -m`
MODEL_NAME="HDP6600"

if [ "$MACHINE" = "x86_64" ]; then
    CONFIGURATION_ID="x86_64"
elif [ "$MACHINE" = "i386" ]; then
   CONFIGURATION_ID="i386"
# The name of the 32bit ARM on a RPI4 with Ubuntu20.04 32bit is armv71
elif [[ "$MACHINE" = "armhf" ]] || [[ "$MACHINE" = "armv7l" ]]; then
   CONFIGURATION_ID="armhf"
elif [ "$MACHINE" = "aarch64" ]; then
   CONFIGURATION_ID="aarch64"
elif [ "$MACHINE" = "mips" ]; then
   CONFIGURATION_ID="mips"
elif [ "$MACHINE" = "mipsel" ]; then
   CONFIGURATION_ID="mipsel"
elif [ "$MACHINE" = "loongarch64" ]; then
   CONFIGURATION_ID="loongarch64"
else
    echo "Not supported architecture: '${MACHINE}'"
    exit 1
fi

ARCHIVE_NAME=$MODEL_NAME-$CONFIGURATION_ID.tar.gz

echo
echo "Begin Installation of ${MODEL_NAME} Card Printer Driver on ${PLATFORM}"


if [ -f ${ARCHIVE_NAME} ]
then
    echo "    Found Installation Archive:  ${ARCHIVE_NAME}"
else
    echo "    Missing Installation Archive:  ${ARCHIVE_NAME}"
    echo "    Target architecture: ${MACHINE} not supported."
    echo "    Installation Terminated"

    exit 1
fi


if [ "$EUID" != 0 ]
then
    echo "    This Installation Script must be run with root privileges."
    echo "    Installation Terminated"
    exit 1
fi


echo "    Begin File Extraction..."

sudo tar -xzv --no-overwrite-dir -f ${ARCHIVE_NAME} -C /
status=$?

if [ $status == 0 ]
then
    echo "    File Extraction Complete."
else
    echo "    File Extraction Failed.  Error:  $status"
    echo "    Installation Terminated"
    exit 1
fi

echo "    Setting driver files permissions..."

sudo chown root:root /usr/lib/cups/filter/rastertofargo*
sudo chmod 755 /usr/lib/cups/filter/rastertofargo*

echo "    Done..."

echo "    Update Device Rules..."

udevadm trigger --action=change
status=$?

if [ $status == 0 ]
then
    echo "    Device Rules Updated."
else
    echo "    Failed to Update Device Rules.  Error:  $status"
    echo "    Installation Terminated"
    exit 1
fi


echo "Installation of ${MODEL_NAME} Card Printer Driver is complete."

